@@ -58,6 +58,42 @@ class ArticleCommentItem(scrapy.Item):
     created_date = scrapy.Field()
 
 
+class PaperCommentItem(scrapy.Item):
+    task_id = scrapy.Field()
+    domain_url = scrapy.Field()
+    domain_id = scrapy.Field()
+    domain_name = scrapy.Field()
+    source_url = scrapy.Field()
+    source_id = scrapy.Field()
+    source_name = scrapy.Field()
+    block_id = scrapy.Field()
+    title = scrapy.Field()
+    cover_url = scrapy.Field()
+    oss_cover_url = scrapy.Field()
+    publish_date = scrapy.Field()
+    url = scrapy.Field()
+    url_md5 = scrapy.Field()
+    author = scrapy.Field()
+    content = scrapy.Field()
+    lang = scrapy.Field()  # 正文语言
+    abstract = scrapy.Field()  # 摘要
+    description_cn = scrapy.Field()
+    description_en = scrapy.Field()
+    keywords = scrapy.Field()  # 关键词
+    doi = scrapy.Field()  # DOI
+    year = scrapy.Field()  # 年份
+    quote = scrapy.Field()  # 引用
+    publish_source = scrapy.Field()  # 发布来源
+    subject = scrapy.Field()  # 学科
+    pages = scrapy.Field()  # 页数
+    word_number = scrapy.Field()  # 字数
+    download_url = scrapy.Field()
+    other_info = scrapy.Field()
+    upload_oss = scrapy.Field()
+    created_date = scrapy.Field()
+    err_msg = scrapy.Field()
+
+
 def get_item(response, source, block, parse=True, uploadOss=True, crawlComment=False):
     item = ArticleItem()
     item["domain_url"] = block["domain_url"]
@@ -101,6 +137,30 @@ def get_comment_item(response, post_result, block, uploadOss=True):
     return item
 
 
+def get_papaer_item(response, source, block, parse=True, uploadOss=True):
+    item = PaperCommentItem()
+    item["domain_url"] = block["domain_url"]
+    item["domain_id"] = block["domain_id"]
+    item["domain_name"] = block["domain_name"]
+    item["block_id"] = block["identification"]
+    item["upload_oss"] = uploadOss
+    if source:
+        item["source_url"] = source["url"]
+        item["source_id"] = source["identification"]
+        item["source_name"] = source["name"]
+        item["upload_oss"] = source.get('upload_oss', False)
+    if response:
+        item["url"] = response.url
+        item["url_md5"] = hashlib.md5(response.url.encode("utf-8")).hexdigest()
+    if parse:
+        content_regex = block.get('content_regex')
+        if content_regex and len(content_regex) > 0:
+            manual_parse(item, response, content_regex)
+        else:
+            auto_parse(item, response)
+    return item
+
+
 def __get_content_html(response, base_url, path):
     html_res = __get_content_extract(response, path)
     if html_res and "" != html_res:
